==> signature_bls-0.15.0.crate: signature_bls-0.15.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.15.0 - 2021-08-16
### Changed
- Dependencies updated.

## v0.14.0 - 2021-08-09
### Changed
- Dependencies updated.

## v0.13.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.12.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-26
### Added
- Add threshold BLS signing.
- PartialSignature
- PartialSignatureVt
- SecretKeyShare
- SecretKey::split
- SecretKey::combine
- Signature::from_partials
- SignatureVt::from_partials
- Fix clippy errors
- Implement format display for existing primitives
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.7.0 - 2021-06-30
### Changed
- Fix clippy warnings.
- Dependencies updated.

## v0.6.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-14
### Changed
- Dependencies updated.

## v0.4.0 - 2021-05-30
### Added
### Changed
- Dependencies updated.
- Fix clippy issues.
### Deleted

## v0.3.0 - 2021-05-17
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.2.0 - 2021-05-10
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.1.2 - 2021-05-03
### Changed
- Dependencies updated.

## v0.1.1 - 2021-04-26
### Changed
- Dependencies updated.

## v0.1.0 - 2021-04-05

- Initial release.

==> signature_bls-0.17.0.crate: signature_bls-0.17.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.17.0 - 2021-08-30
### Changed
- Dependencies updated.

## v0.16.0 - 2021-08-23
### Changed
- Replace std:: modules with core:: and alternate implementations
- Dependencies updated.

## v0.15.0 - 2021-08-16
### Changed
- Dependencies updated.

## v0.14.0 - 2021-08-09
### Changed
- Dependencies updated.

## v0.13.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.12.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-26
### Added
- Add threshold BLS signing.
- PartialSignature
- PartialSignatureVt
- SecretKeyShare
- SecretKey::split
- SecretKey::combine
- Signature::from_partials
- SignatureVt::from_partials
- Fix clippy errors
- Implement format display for existing primitives
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.7.0 - 2021-06-30
### Changed
- Fix clippy warnings.
- Dependencies updated.

## v0.6.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-14
### Changed
- Dependencies updated.

## v0.4.0 - 2021-05-30
### Added
### Changed
- Dependencies updated.
- Fix clippy issues.
### Deleted

## v0.3.0 - 2021-05-17
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.2.0 - 2021-05-10
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.1.2 - 2021-05-03
### Changed
- Dependencies updated.

## v0.1.1 - 2021-04-26
### Changed
- Dependencies updated.

## v0.1.0 - 2021-04-05

- Initial release.
